@@ -14,12 +14,15 @@ class Tournament:
     def getMatches(self):
         return leaguepedia.getMatches(tournamentName=self.name)
 
-    def getTeams(self):
-        return leaguepedia.getTeams(self.name)
+    def getTeams(self, isMapped=False, thumbnailRedirect=False):
+        return leaguepedia.getTeams(self.name, isMapped, thumbnailRedirect)
 
     def getPlayers(self, roleFilter=["Top", "Jungle", "Mid", "Bot", "Support"], thumbnailRedirect=False):
         return leaguepedia.getPlayers(self.name, roleFilter, thumbnailRedirect)
 
+    def getMatchSchedule(self):
+        return leaguepedia.getMatchSchedule(self.name)
+
 class Match:
     def __init__(self, _uniqueMatch):
         self._uniqueMatch = _uniqueMatch
@@ -94,3 +97,12 @@ class Player:
 
     def __str__(self):
         return "{} {}".format(self.team, self.name)
+
+class Team:
+    def __init__(self, name, short):
+        self.name = name
+        self.short = short
+        self.thumbnail = None
+
+    def __str__(self):
+        return self.short
