@@ -11,16 +11,17 @@ Params:
     Leaguepedia tournament name
 Player data format (json)
 {
-    "Team":"T1"
-    "Player":"Teddy"
-    "FileName":"SKT Teddy 2019 Split 2.png"
+    Team: "SeolHaeOne Prince"
+    Role: "Bot"
+    FileName: "SP Trigger 2020 Split 2.png"
+    ID: "Trigger"
 }
 """
 PLAYERS_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
-    &tables=Tournaments=T,TournamentPlayers=TP,PlayerImages=PI
-    &fields=TP.Team,TP.Player,TP.Role,PI.FileName
+    &tables=Tournaments=T,TournamentPlayers=TP,PlayerImages=PI,PlayerRedirects=PR
+    &fields=TP.Team,PR.ID,TP.Role,PI.FileName
     &where={}
-    &join_on=T.OverviewPage=TP.OverviewPage,TP.Link=PI.Link
+    &join_on=T.OverviewPage=TP.OverviewPage,TP.Link=PI.Link,TP.Player=PR.AllName
     &order_by=PI.FileName DESC
     &group_by=TP.Player"""
 
@@ -29,19 +30,36 @@ Params:
     Leaguepedia tournament name
 Team data format (json)
 {
-    "Team1":"DragonX"
+    "Team1":"APK Prince",
+    "TeamName":"SeolHaeOne Prince",
+    "Short":"SP"
 }
 """
 TEAMS_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
-    &tables=ScoreboardGames=SG
-    &fields=SG.Team1
+    &tables=ScoreboardGames=SG,TeamRedirects=TR,Teams=T
+    &fields=SG.Team1,TR._pageName=TeamName,T.Short
     &where={}
+    &join_on=SG.Team1=TR.AllName,TR._pageName=T._pageName
     &group_by=SG.Team1"""
 
-TEAM_REDIRECT_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
-    &tables=TeamRedirects=TR
-    &fields=TR._pageName=TeamName
-    &where=TR.AllName='{}'"""
+"""
+Params:
+    Leaguepedia tournament name
+Match schedule data format (json)
+{
+    DateTime UTC    "2021-01-13 08:00:00"
+    Team1   "Gen.G"
+    Team2   "KT Rolster"
+    BestOf  "3"
+    Tab "Week 1"
+    DateTime UTC__precision "0"
+}
+"""
+MATCH_SCHEDULE_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
+    &tables=MatchSchedule=MS
+    &fields=MS.DateTime_UTC,MS.Team1,MS.Team2,MS.BestOf,MS.Tab
+    &where={}
+    &order_by=MS.DateTime_UTC ASC"""
 
 """
 Params:
@@ -129,7 +147,7 @@ GAMES_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&l
 Params:
     FileName provided in game data object
 """
-PLAYER_THUMBNAIL_URL = "https://lol.gamepedia.com/Special:Redirect/file/{}"
+LEAGUEPEDIA_THUMBNAIL_URL = "https://lol.gamepedia.com/Special:Redirect/file/{}"
 
 DDRAGON_VERSIONS_URL = "https://ddragon.leagueoflegends.com/api/versions.json"
 
